Coverage report

File |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | ---
src / dataknobs_bots / api / dependencies.py |  | 35 | 35 | 0 |  | 0%
src / dataknobs_bots / api / exceptions.py |  | 58 | 58 | 3 |  | 0%
src / dataknobs_bots / bot / base.py |  | 304 | 271 | 2 |  | 11%
src / dataknobs_bots / bot / context.py |  | 19 | 5 | 0 |  | 74%
src / dataknobs_bots / bot / manager.py |  | 103 | 71 | 7 |  | 31%
src / dataknobs_bots / bot / registry.py |  | 139 | 97 | 14 |  | 30%
src / dataknobs_bots / config / resolution.py |  | 64 | 64 | 6 |  | 0%
src / dataknobs_bots / knowledge / query / expander.py |  | 73 | 58 | 0 |  | 21%
src / dataknobs_bots / knowledge / query / transformer.py |  | 74 | 54 | 0 |  | 27%
src / dataknobs_bots / knowledge / rag.py |  | 284 | 88 | 1 |  | 69%
src / dataknobs_bots / knowledge / retrieval / formatter.py |  | 86 | 66 | 0 |  | 23%
src / dataknobs_bots / knowledge / retrieval / merger.py |  | 84 | 11 | 0 |  | 87%
src / dataknobs_bots / memory / base.py |  | 3 | 0 | 27 |  | 100%
src / dataknobs_bots / memory / buffer.py |  | 13 | 5 | 0 |  | 62%
src / dataknobs_bots / memory / vector.py |  | 50 | 38 | 1 |  | 24%
src / dataknobs_bots / middleware / base.py |  | 4 | 0 | 49 |  | 100%
src / dataknobs_bots / middleware / cost.py |  | 124 | 103 | 0 |  | 17%
src / dataknobs_bots / middleware / logging.py |  | 55 | 42 | 0 |  | 24%
src / dataknobs_bots / reasoning / base.py |  | 3 | 0 | 31 |  | 100%
src / dataknobs_bots / reasoning / react.py |  | 73 | 64 | 0 |  | 12%
src / dataknobs_bots / reasoning / simple.py |  | 5 | 1 | 0 |  | 80%
src / dataknobs_bots / registry / backend.py |  | 30 | 13 | 2 |  | 57%
src / dataknobs_bots / registry / memory.py |  | 67 | 47 | 3 |  | 30%
src / dataknobs_bots / registry / models.py |  | 17 | 2 | 6 |  | 88%
src / dataknobs_bots / registry / portability.py |  | 32 | 21 | 0 |  | 34%
src / dataknobs_bots / tools / knowledge_search.py |  | 13 | 0 | 0 |  | 100%
Total |  | 1812 | 1214 | 152 |  | 33%

No items found using the specified filter.